[CMF-checkins] CVS: CMF/CMFCore/interfaces - portal_skins.py:1.8
Yvo Schubbe
y.2004_ at wcm-solutions.de
Thu Feb 5 07:52:31 EST 2004
Update of /cvs-repository/CMF/CMFCore/interfaces
In directory cvs.zope.org:/tmp/cvs-serv7121/CMFCore/interfaces
Modified Files:
portal_skins.py
Log Message:
- synced SkinsTool, SkinsContainer and their interfaces so they have the same permissions and docstrings
- replaced 'Not implemented' by NotImplementedError
=== CMF/CMFCore/interfaces/portal_skins.py 1.7 => 1.8 ===
--- CMF/CMFCore/interfaces/portal_skins.py:1.7 Mon Jan 6 15:39:34 2003
+++ CMF/CMFCore/interfaces/portal_skins.py Thu Feb 5 07:52:00 2004
@@ -23,43 +23,54 @@
from Interface import Base as Interface
-class portal_skins(Interface):
- '''An object that provides skins to a portal object.
- '''
- id = Attribute('id', 'Must be set to "portal_skins"')
+class SkinsContainer(Interface):
+ """ An object that provides skins.
+ """
- # Private
def getSkinPath(name):
- """Converts a skin name to a skin path.
+ """ Convert a skin name to a skin path.
+
+ Permission -- Access contents information
"""
- # Public
def getDefaultSkin():
- """Returns the default skin name.
+ """ Get the default skin name.
+
+ Permission -- Access contents information
"""
- # Public
def getRequestVarname():
- """Returns the variable name to look for in the REQUEST.
+ """ Get the variable name to look for in the REQUEST.
+
+ Permission -- Access contents information
"""
- # Private
def getSkinByPath(path, raise_exc=0):
- """Returns a skin at the given path.
+ """ Get a skin at the given path.
A skin path is of the format:
'some/path, some/other/path, ...' The first part has precedence.
A skin is a specially wrapped object that looks through the layers
in the correct order.
+
+ Permission -- Python only
"""
- # Private
def getSkinByName(name):
- """Returns the named skin.
+ """ Get the named skin.
+
+ Permission -- Python only
"""
- # Public
+
+class portal_skins(SkinsContainer):
+ """ An object that provides skins to a portal object.
+ """
+ id = Attribute('id', 'Must be set to "portal_skins"')
+
def getSkinSelections():
- """Returns the sorted list of available skin names.
+ """ Get the sorted list of available skin names.
+
+ Permission -- Always available
"""
More information about the CMF-checkins
mailing list